@@ -15,8 +15,9 @@ from python_spartan.services.inspire import InspireService
 from python_spartan.services.layer import LayerService
 from python_spartan.services.migrate import MigrateService
 from python_spartan.services.model import ModelService
-from python_spartan.services.parser import ParserService
-from python_spartan.services.plotter import PlotterService
+
+# from python_spartan.services.parser import ParserService
+# from python_spartan.services.plotter import PlotterService
 from python_spartan.services.request import RequestService
 from python_spartan.services.response import ResponseService
 from python_spartan.services.route import RouteService
@@ -25,27 +26,28 @@ from python_spartan.services.test import TestService
 
 alembic_cfg = Config("alembic.ini")
 
-app = typer.Typer()
+app = typer.Typer(no_args_is_help=True)
+
 
 model_app = typer.Typer()
 app.add_typer(
     model_app, name="model", help="Manages the creation and deletion of model classes."
 )
 
-parser_app = typer.Typer()
-app.add_typer(
-    parser_app,
-    name="parser",
-    help="Manages the creation and deletion of parser classes.",
-)
+# parser_app = typer.Typer()
+# app.add_typer(
+#     parser_app,
+#     name="parser",
+#     help="Manages the creation and deletion of parser classes.",
+# )
 
 
-plotter_app = typer.Typer()
-app.add_typer(
-    plotter_app,
-    name="plotter",
-    help="Manages the creation and deletion of plotter classes.",
-)
+# plotter_app = typer.Typer()
+# app.add_typer(
+#     plotter_app,
+#     name="plotter",
+#     help="Manages the creation and deletion of plotter classes.",
+# )
 
 
 handler_app = typer.Typer()
@@ -104,7 +106,12 @@ app.add_typer(
 )
 
 layer_app = typer.Typer()
-app.add_typer(layer_app, name="layer", help="Build and publish your AWS Lambda layers.")
+app.add_typer(
+    layer_app, name="layer", help="Compress local packages into single zip file."
+)
+
+test_app = typer.Typer()
+app.add_typer(test_app, name="test", help="Run and create tests.")
 
 
 def run_poetry_command(command):
@@ -139,22 +146,22 @@ def model_create(name: str):
         print(f"Error creating model: {e}")
 
 
-@parser_app.command("create", help="Create a new parser class.")
-def parser_create(name: str):
-    try:
-        service = ParserService(name)
-        service.create_parser_file()
-    except Exception as e:
-        print(f"Error creating parser: {e}")
+# @parser_app.command("create", help="Create a new parser class.")
+# def parser_create(name: str):
+#     try:
+#         service = ParserService(name)
+#         service.create_parser_file()
+#     except Exception as e:
+#         print(f"Error creating parser: {e}")
 
 
-@plotter_app.command("create", help="Create a new plotter class.")
-def plotter_create(name: str):
-    try:
-        service = PlotterService(name)
-        service.create_plotter_file()
-    except Exception as e:
-        print(f"Error creating plotter: {e}")
+# @plotter_app.command("create", help="Create a new plotter class.")
+# def plotter_create(name: str):
+#     try:
+#         service = PlotterService(name)
+#         service.create_plotter_file()
+#     except Exception as e:
+#         print(f"Error creating plotter: {e}")
 
 
 @model_app.command("delete", help="Delete an existing model class.")
@@ -357,18 +364,41 @@ def serve(port: int = typer.Option(8888, "--port", "-p", help="Set port number."
         print(f"Error running serving the app: {e}")
 
 
-@app.command("test", help="Run tests with optional coverage and report.")
-def test(
-    coverage: str = typer.Option(
-        None, "-c", "--coverage", help="Path for coverage. Omit to skip coverage.."
+# Add the 'create' subcommand
+@test_app.command("create")
+def create_test(
+    test_name: str,
+    integration: bool = typer.Option(False, "--integration", "-i", help="Create an integration test."),
+    output: str = typer.Option(None, "--output", "-o", help="Specify the output directory for the test file."),
+):
+    """
+    Create a new test file with the specified name. Use --integration to create an integration test inside tests/feature.
+    Use --output to specify a custom output directory for the test file.
+    """
+    try:
+        # Create a new test file using TestService, pass integration flag and output path
+        test_service = TestService(name=test_name, integration=integration, output_path=output)
+        test_service.create_test_file()
+    except Exception as e:
+        print(f"Error creating test: {e}")
+
+# Add the 'run' subcommand
+@test_app.command("run")
+def run_tests(
+    coverage: bool = typer.Option(
+        False, "--coverage", "-c", help="Run tests with coverage reporting."
     ),
     report: str = typer.Option(
-        None, "-r", "--report", help="Type of coverage report. For example: 'html'."
+        None, "--report", "-r", help="Generate a specific report. For example: 'html'."
     ),
 ):
+    """
+    Run tests, optionally with coverage and report generation.
+    """
     try:
-        runner = TestService(coverage, report)
-        runner.run()
+        # Run tests using TestService
+        test_service = TestService(coverage=coverage, report=report)
+        test_service.run_tests()
     except Exception as e:
         print(f"Error running tests: {e}")
 
@@ -486,33 +516,5 @@ def layer_create(
         print(f"Error creating layer: {e}")
 
 
-# @layer_app.command("publish", help="Publish the layer to AWS.")
-# def layer_publish(
-#     name: str = typer.Argument(..., help="Name of the layer."),
-#     description: str = typer.Option(
-#         "", "--desc", "-d", help="Description of the layer."
-#     ),
-#     runtimes: str = typer.Option(
-#         "python3.11",
-#         "--runtimes",
-#         "-r",
-#         help="Compatible runtimes for the layer.",
-#     ),
-#     zip_file: str = typer.Option(
-#         ..., "--path", "-p", help="Path to the zip file to publish."
-#     ),
-# ):
-#     try:
-#         # Initialize LayerService with the name, description, and runtimes
-#         layer_service = LayerService(
-#             layer_name=name, description=description, compatible_runtimes=[runtimes]
-#         )
-#         # Publish the Lambda Layer using the provided zip file path
-#         layer_service.publish_layer(zip_file)
-#         print(f"Layer {name} published successfully.")
-#     except Exception as e:
-#         print(f"Error publishing layer: {e}")
-
-
 if __name__ == "__main__":
     app()
